### Changelog

## auto-genesis-telemetry-beta-v0.0.3 (2025-03-04)

### BREAKING CHANGE

- Version management now follows semantic versioning strictly
across all packages. Manual version updates are replaced with automated
updates based on commit messages.
- Version management now follows semantic versioning strictly
across all packages. Manual version updates are replaced with automated
updates based on commit messages.
- Initial implementation sets the foundation for the SDK.
Users will need to follow the new configuration format and installation process.

### Feat

- add context propagation to tracing
- update to minor version
- initial commit
- implement automated semantic versioning and release management
- implement automated semantic versioning and release management
- *****: Implement semantic release
- implement OpenTelemetry SDK with automated tooling

### Fix

- **auto_genesis_sdk**: install packages without venv
- **auto_genesis_sdk**: install local sdk package for running pytest
- **auto_genesis_sdk**: promote to beta
- install dev deps in pipeline
- add testing to pipeline
- update readme to reflect context propagation changes in tracing service
- update deps to use the latest version
- Added --system flag and modified commitizen usage
- update in azure pipelines for sdk publish
- add and run commit bump on telemetry update for sdk
- use latest version of telemetry in sdk
- install packages on system
- update readme after refactoring services
- update readme
- update telemetry version to 0.0.5
- update telemetry deps to 0.0.5
- add commitizen for changelog managing
- add dep for telemetry
- add deps for telemetry in pyproject
- feat: update package name to -alpha
- cleanup changelog
- clean up changelog with commitizen
- chagnes to changelog generation
- add script to add changelog commit link
- add get_commit_info
- update in parser for git template
- update in template for changelog
- update in template for changelog
- cleanup changelog
- add links of commit in the changelog
- add commit links to the changelog
- add template to the changelog
- fix in the readme
- reset version to v0.0.1
- reset all versions to 0.0.1
- remove existing changelog

### Refactor

- apply pre-commit hook changes across repo
- update poetry lock
- testing commitizen package for generating changelogs

## auto-genesis-telemetry-v0.0.3 (2025-07-24)

### Fix

- **telemtry**: Implement audit logger

## auto-genesis-telemetry-v0.0.2 (2025-07-24)

### Fix

- initial publish of package to pypi
- initial release of auto-genesis-sdk to pypi

## auto-genesis-telemetry-v0.0.1 (2025-03-04)

### Fix

- initial release of auto-genesis-telemetry to pypi

## auto-genesis-telemetry-v0.0.0 (2025-03-04)

### BREAKING CHANGE

- Version management now follows semantic versioning strictly
across all packages. Manual version updates are replaced with automated
updates based on commit messages.
- Version management now follows semantic versioning strictly
across all packages. Manual version updates are replaced with automated
updates based on commit messages.
- Initial implementation sets the foundation for the SDK.
Users will need to follow the new configuration format and installation process.

### Feat

- update to minor version
- initial commit
- implement automated semantic versioning and release management
- implement automated semantic versioning and release management
- *****: Implement semantic release
- implement OpenTelemetry SDK with automated tooling

### Fix

- update readme after refactoring services
- update readme
- update telemetry version to 0.0.5
- update telemetry deps to 0.0.5
- 2
- 1
- somehting
- cleanup changelog
- cleanup changelog
- cleanup changelog
- cleanup changelog
- cleanup changelog
- update readme
- add commitizen for changelog managing
- add dep for telemetry
- add deps for telemetry in pyproject
- feat: update package name to -alpha
- cleanup changelog
- clean up changelog with commitizen
- chagnes to changelog generation
- add script to add changelog commit link
- cleanup changelog
- changes 1
- changes
- add get_commit_info
- update in parser for git template
- update in template for changelog
- update in template for changelog
- cleanup changelog
- add links of commit in the changelog
- add commit links to the changelog
- add template to the changelog
- fix in the readme
- reset version to v0.0.1
- reset all versions to 0.0.1
- remove existing changelog

### Refactor

- apply pre-commit hook changes across repo
- update poetry lock
- testing commitizen package for generating changelogs
